@@ -47,7 +47,7 @@ void AnnounceReq::print()
 
 void AnnounceReq::encode(QByteArray &arr) const
 {
-    BEncoder enc(new BEncoderBufferOutput(arr));
+    BEncoder enc(std::make_unique<BEncoderBufferOutput>(arr));
     enc.beginDict();
     {
         enc.write(ARG);
