@@ -42,7 +42,7 @@ void AnnounceRsp::print()
 
 void AnnounceRsp::encode(QByteArray &arr) const
 {
-    BEncoder enc(new BEncoderBufferOutput(arr));
+    BEncoder enc(std::make_unique<BEncoderBufferOutput>(arr));
     enc.beginDict();
     {
         enc.write(RSP);
