@@ -377,19 +377,15 @@ void Peer::handleExtendedPacket(const Uint8 *packet, Uint32 size)
 void Peer::handleExtendedHandshake(const Uint8 *packet, Uint32 size)
 {
     QByteArray tmp = QByteArray::fromRawData((const char *)packet, size);
-    BNode *node = nullptr;
     try {
         BDecoder dec(tmp, false, 2);
-        node = dec.decode();
-        if (!node || node->getType() != BNode::DICT) {
-            delete node;
+        const std::unique_ptr<BDictNode> dict = dec.decodeDict();
+        if (!dict) {
             return;
         }
 
-        BDictNode *dict = (BDictNode *)node;
         BDictNode *mdict = dict->getDict(QByteArrayLiteral("m"));
         if (!mdict) {
-            delete node;
             return;
         }
 
@@ -427,7 +423,6 @@ void Peer::handleExtendedHandshake(const Uint8 *packet, Uint32 size)
                         Out(SYS_GEN | LOG_NOTICE) << "Wrong or too high metadata size: " << metadata_size << ". Killing peer... " << endl;
                         Out(SYS_GEN | LOG_NOTICE) << "Maximum supported metadata (torrent file) size: " << MAX_METADATA_SIZE << endl;
                         kill();
-                        delete node;
                         return;
                     }
 
@@ -449,7 +444,6 @@ void Peer::handleExtendedHandshake(const Uint8 *packet, Uint32 size)
         // just ignore invalid packets
         Out(SYS_CON | LOG_DEBUG) << "Invalid extended packet" << endl;
     }
-    delete node;
 }
 
 Uint32 Peer::sendData(const Uint8 *data, Uint32 len)
@@ -643,7 +637,7 @@ void Peer::sendExtProtHandshake(Uint16 port, Uint32 metadata_size, bool partial_
         return;
 
     QByteArray arr;
-    BEncoder enc(new BEncoderBufferOutput(arr));
+    BEncoder enc(std::make_unique<BEncoderBufferOutput>(arr));
     enc.beginDict();
     enc.write(QByteArrayLiteral("m"));
     // supported messages
@@ -716,7 +710,7 @@ void Peer::sendChoke()
     if (!stats.has_upload_slot)
         return;
 
-    sock->addPacket(Packet::Ptr(new Packet(CHOKE)));
+    sock->addPacket(Packet::create(CHOKE));
     stats.has_upload_slot = false;
 }
 
@@ -725,13 +719,13 @@ void Peer::sendUnchoke()
     if (stats.has_upload_slot)
         return;
 
-    sock->addPacket(Packet::Ptr(new Packet(UNCHOKE)));
+    sock->addPacket(Packet::create(UNCHOKE));
     stats.has_upload_slot = true;
 }
 
 void Peer::sendEvilUnchoke()
 {
-    sock->addPacket(Packet::Ptr(new Packet(UNCHOKE)));
+    sock->addPacket(Packet::create(UNCHOKE));
     stats.has_upload_slot = false;
 }
 
@@ -740,7 +734,7 @@ void Peer::sendInterested()
     if (stats.am_interested == true)
         return;
 
-    sock->addPacket(Packet::Ptr(new Packet(INTERESTED)));
+    sock->addPacket(Packet::create(INTERESTED));
     stats.am_interested = true;
 }
 
@@ -749,58 +743,58 @@ void Peer::sendNotInterested()
     if (stats.am_interested == false)
         return;
 
-    sock->addPacket(Packet::Ptr(new Packet(NOT_INTERESTED)));
+    sock->addPacket(Packet::create(NOT_INTERESTED));
     stats.am_interested = false;
 }
 
 void Peer::sendRequest(const Request &r)
 {
-    sock->addPacket(Packet::Ptr(new Packet(r, bt::REQUEST)));
+    sock->addPacket(Packet::create(r, bt::REQUEST));
 }
 
 void Peer::sendCancel(const Request &r)
 {
-    sock->addPacket(Packet::Ptr(new Packet(r, bt::CANCEL)));
+    sock->addPacket(Packet::create(r, bt::CANCEL));
 }
 
 void Peer::sendReject(const Request &r)
 {
-    sock->addPacket(Packet::Ptr(new Packet(r, bt::REJECT_REQUEST)));
+    sock->addPacket(Packet::create(r, bt::REJECT_REQUEST));
 }
 
 void Peer::sendHave(Uint32 index)
 {
-    sock->addPacket(Packet::Ptr(new Packet(index, bt::HAVE)));
+    sock->addPacket(Packet::create(index, bt::HAVE));
 }
 
 void Peer::sendPort(Uint16 port)
 {
-    sock->addPacket(Packet::Ptr(new Packet(port)));
+    sock->addPacket(Packet::create(port));
 }
 
 void Peer::sendBitSet(const BitSet &bs)
 {
-    sock->addPacket(Packet::Ptr(new Packet(bs)));
+    sock->addPacket(Packet::create(bs));
 }
 
 void Peer::sendHaveAll()
 {
-    sock->addPacket(Packet::Ptr(new Packet(bt::HAVE_ALL)));
+    sock->addPacket(Packet::create(bt::HAVE_ALL));
 }
 
 void Peer::sendHaveNone()
 {
-    sock->addPacket(Packet::Ptr(new Packet(bt::HAVE_NONE)));
+    sock->addPacket(Packet::create(bt::HAVE_NONE));
 }
 
 void Peer::sendSuggestPiece(Uint32 index)
 {
-    sock->addPacket(Packet::Ptr(new Packet(index, bt::SUGGEST_PIECE)));
+    sock->addPacket(Packet::create(index, bt::SUGGEST_PIECE));
 }
 
 void Peer::sendAllowedFast(Uint32 index)
 {
-    sock->addPacket(Packet::Ptr(new Packet(index, bt::ALLOWED_FAST)));
+    sock->addPacket(Packet::create(index, bt::ALLOWED_FAST));
 }
 
 bool Peer::sendChunk(Uint32 index, Uint32 begin, Uint32 len, Chunk *ch)
@@ -830,13 +824,13 @@ bool Peer::sendChunk(Uint32 index, Uint32 begin, Uint32 len, Chunk *ch)
      *          .arg(index).arg(begin).arg(len).arg((quint64)ch,0,16).arg((quint64)ch->getData(),0,16)
      *          << endl;;
      */
-    sock->addPacket(Packet::Ptr(new Packet(index, begin, len, ch)));
+    sock->addPacket(Packet::create(index, begin, len, ch));
     return true;
 }
 
 void Peer::sendExtProtMsg(Uint8 id, const QByteArray &data)
 {
-    sock->addPacket(Packet::Ptr(new Packet(id, data)));
+    sock->addPacket(Packet::create(id, data));
 }
 
 void Peer::clearPendingPieceUploads()
